##  Editing in Matrix Reports
Within the report, users are able to quickly modify Tags, Attributes, and Relations to fact sheets using the edit pane. In order to access the edit pane in a landscape report, select any of the fact sheets, that is click on the one that requires modification. A pane will appear on the right-hand side, displaying information about the fact sheet and offering the ability to edit its properties. Any adjustments made are immediately implemented within both the report and the fact sheet itself. This report also allows doing inline editing by clicking on the enabling editing button. With this enabled, you can directly add or delete cells directly on the matrix.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753f3417a441014830cd0999022a332_LowRes.png)
By clicking the Tags area, you can directly add or remove tags in the editing pane. One can add new relations by clicking on the + Add relation icon and selecting one of the fact sheet items. Only the fact sheet data that is actually displayed in the matrix report is editable in the pane. Choosing a different View will result in a different attribute being displayed which then can be edited in the edit pane.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ed7097a441014b103ff510fa81404_LowRes.gif)
